# cloudenv-python

## How to Install

$ pip install cloudenv

## How to Use

```
import os
import cloudenv

cloudenv.load_cloudenv()
os.getenv("AWS_SECRET_ACCESS_KEY")
```

## Learn More

Visit CloudEnv.com